Yori provides a set of tools to grid geophysical variables from satellite data
and aggregate them.

For information on how to use, please see the documentation page at:
https://sips.ssec.wisc.edu/docs/yori.html
